@@ -6,7 +6,7 @@ use strict;
 use Carp;
 use Regexp::RegGrp;
 
-our $VERSION        = '0.03_01';
+our $VERSION        = '0.03_03';
 
 our $DICTIONARY     = {
     'STRING1'   => qr~"(?>(?:(?>[^"\\]+)|\\.|\\"|\\\s)*)"~,
@@ -315,7 +315,7 @@ CSS::Packer - Another CSS minifier
 
 =head1 VERSION
 
-Version 0.03_01
+Version 0.03_03
 
 =head1 DESCRIPTION
 
@@ -335,7 +335,7 @@ To return a scalar without changing the input simply use (e.g. example 2):
 
 For backward compatibility it is still possible to call 'minify' as a function:
 
-    CSS::Packer::minify( $javascript, $opts );
+    CSS::Packer::minify( $scalarref, $opts );
 
 First argument must be a scalarref of CSS-Code.
 Second argument must be a hashref of options. The only option is
